@@ -10,18 +10,18 @@ import subprocess
 import sys
 import types
 from importlib.util import spec_from_loader
+from typing import Set
 
 __title__ = "anysearch"
-__version__ = "0.1.1"
+__version__ = "0.1.3"
 __author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
 __copyright__ = "2022 Artur Barseghyan"
 __license__ = "MIT"
 
-
 LOGGER = logging.getLogger(__name__)
 
 
-def get_installed_packages() -> set[str]:
+def get_installed_packages() -> Set[str]:
     """Get installed packages.
 
     :return: Set of installed packages.
@@ -38,7 +38,7 @@ def get_installed_packages() -> set[str]:
 
 
 def check_if_package_is_installed(
-    package_name, installed_packages: set[str] = None
+    package_name, installed_packages: Set[str] = None
 ) -> bool:
     """Check if a package is installed.
 
@@ -247,7 +247,57 @@ class _SearchMovedItems(_LazyModule):
 
 
 _search_moved_attributes = [
-    # TODO add more moved items
+    # elasticsearch/opensearch
+    # **********************************************
+    # **************** Moved modules ***************
+    # **********************************************
+    # .
+
+    # **********************************************
+    # ************* Moved attributes ***************
+    # **********************************************
+    # .
+    MovedAttribute("__version__", "elasticsearch", "opensearchpy"),
+    MovedAttribute(
+        "AnySearch",
+        "elasticsearch",
+        "opensearchpy",
+        "Elasticsearch",
+        "OpenSearch",
+    ),
+    MovedAttribute("Transport", "elasticsearch", "opensearchpy"),
+    MovedAttribute("ConnectionPool", "elasticsearch", "opensearchpy"),
+    MovedAttribute("ConnectionSelector", "elasticsearch", "opensearchpy"),
+    MovedAttribute("RoundRobinSelector", "elasticsearch", "opensearchpy"),
+    MovedAttribute("JSONSerializer", "elasticsearch", "opensearchpy"),
+    MovedAttribute("Connection", "elasticsearch", "opensearchpy"),
+    MovedAttribute("RequestsHttpConnection", "elasticsearch", "opensearchpy"),
+    MovedAttribute("Urllib3HttpConnection", "elasticsearch", "opensearchpy"),
+    MovedAttribute("ImproperlyConfigured", "elasticsearch", "opensearchpy"),
+    MovedAttribute(
+        "AnySearchException",
+        "elasticsearch",
+        "opensearchpy",
+        "ElasticsearchException",
+        "OpenSearchException",
+    ),
+    MovedAttribute("SerializationError", "elasticsearch", "opensearchpy"),
+    MovedAttribute("TransportError", "elasticsearch", "opensearchpy"),
+    MovedAttribute("NotFoundError", "elasticsearch", "opensearchpy"),
+    MovedAttribute("ConflictError", "elasticsearch", "opensearchpy"),
+    MovedAttribute("RequestError", "elasticsearch", "opensearchpy"),
+    MovedAttribute("ConnectionError", "elasticsearch", "opensearchpy"),
+    MovedAttribute("SSLError", "elasticsearch", "opensearchpy"),
+    MovedAttribute("ConnectionTimeout", "elasticsearch", "opensearchpy"),
+    MovedAttribute("AuthenticationException", "elasticsearch", "opensearchpy"),
+    MovedAttribute("AuthorizationException", "elasticsearch", "opensearchpy"),
+    MovedAttribute(
+        "AnySearchDeprecationWarning",
+        "elasticsearch",
+        "opensearchpy",
+        "ElasticsearchDeprecationWarning",
+        "OpenSearchDeprecationWarning",
+    ),
 ]
 
 for _search_attr in _search_moved_attributes:
@@ -260,7 +310,6 @@ try:
 except:
     pass
 
-
 _SearchMovedItems._moved_attributes = _search_moved_attributes
 
 search = _SearchMovedItems(__name__ + ".search")
@@ -337,9 +386,13 @@ _search_dsl_moved_attributes = [
     MovedAttribute("InnerDoc", "elasticsearch_dsl", "opensearch_dsl"),
     MovedAttribute("MetaField", "elasticsearch_dsl", "opensearch_dsl"),
     # .exceptions
-    # MovedAttribute(
-    #     "ElasticsearchDslException", "elasticsearch_dsl", "opensearch_dsl"
-    # ),
+    MovedAttribute(
+        "AnySearchDslException",
+        "elasticsearch_dsl",
+        "opensearch_dsl",
+        "ElasticsearchDslException",
+        "OpenSearchDslException",
+    ),
     MovedAttribute("IllegalOperation", "elasticsearch_dsl", "opensearch_dsl"),
     MovedAttribute("UnknownDslObject", "elasticsearch_dsl", "opensearch_dsl"),
     MovedAttribute(
@@ -419,7 +472,12 @@ _search_dsl_moved_attributes = [
     # **********************************************
     # ********** Additional moved attributes *******
     # **********************************************
-    MovedAttribute("AggsProxy", "elasticsearch_dsl.search", "opensearch_dsl.search"),
+    MovedAttribute(
+        "AggsProxy", "elasticsearch_dsl.search", "opensearch_dsl.search"
+    ),
+    MovedAttribute(
+        "MoreLikeThis", "elasticsearch_dsl.query", "opensearch_dsl.query"
+    ),
 ]
 
 for _search_dsl_attr in _search_dsl_moved_attributes:
@@ -507,8 +565,9 @@ _django_search_dsl_moved_attributes = [
     # ********* Additional moved attributes ********
     # **********************************************
     MovedAttribute(
-        "registry", "django_elasticsearch_dsl.registries",
-        "django_opensearch_dsl.registries"
+        "registry",
+        "django_elasticsearch_dsl.registries",
+        "django_opensearch_dsl.registries",
     ),
 ]
 
